<?php
/**
 * testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_testimonial_section' ) ) :
  /**
   * Add testimonial section
   *
   *@since Graduate Pro 1.0
   */
  function graduate_pro_add_testimonial_section() {

    // Check if testimonial is enabled on frontpage
    $testimonial_enable = apply_filters( 'graduate_pro_section_status', true, 'testimonial_enable' );
    if ( true !== $testimonial_enable ) {
      return false;
    }

    // Get testimonial section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_testimonial_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render testimonial section now.
    graduate_pro_render_testimonial_section( $section_details );
  }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_testimonial_section', 75 );


if ( ! function_exists( 'graduate_pro_get_testimonial_section_details' ) ) :
  /**
   * testimonial section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input testimonial section details.
   */
  function graduate_pro_get_testimonial_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // testimonial type
    $testimonial_type  = $options['testimonial_content_type'];

    $content = array();
    switch ( $testimonial_type ) {
        case 'demo':
            $names = array( 1 => esc_html__( 'Andy Jones', 'graduate-pro' ), 2 => esc_html__( 'Sara Smith', 'graduate-pro' ), 3 => esc_html__( 'Steve David', 'graduate-pro' ), 4 => esc_html__( 'Mitju Subba', 'graduate-pro' ), 5 => esc_html__( 'Anna Nicole', 'graduate-pro' ) );
            for( $i = 1; $i <= 5; $i++ ) {
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/testimonial-0' . $i . '.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['title']        = $names[$i];
                $content[$i]['excerpt']      = esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Ut id lacus id tortor facilisis...', 'graduate-pro' );
                $content[$i]['alt']          = esc_attr__( 'News & Events Image', 'graduate-pro' );
            }
            $content[1]['excerpt']           = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut id lacus id tortor facilisis cursus sed dictum ex. Donec convallis urna ut tincidunt egestas. Fusce sodales vestibulum vulputate...', 'graduate-pro' );
        break;

        case 'post':
            $ids = array();

            for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'testimonial_post_id_'.$i ] ) ) {
                    $id = $options[ 'testimonial_post_id_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'post',
                'post__in'       => $ids,
            );
        break;

        case 'testimonial':
            $ids = array();

            for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'tp_testimonial_post_id_'.$i ] ) ) {
                    $id = $options[ 'tp_testimonial_post_id_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'tp-testimonial',
                'post__in'       => $ids,
            );
        break;

        default:
        break;
    }

    if ( 'demo' != $testimonial_type ) {
        // Fetch posts.
        $posts = get_posts( $args );

        if ( ! empty( $posts ) ) {

            $i = 1;
            foreach ( $posts as $key => $post ) {
                $page_id = $post->ID;
                $img_array = null;
                if ( ( count( $posts ) % 2 != 0 ) && ( $i == 1 ) ) :
                    if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-600x522.jpg';
                    }
                    $content[$i]['excerpt']  = graduate_pro_trim_content( 22, $post  );
                else :
                    if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'graduate_pro_trending_courses' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-200x200.jpg';
                    }
                    $content[$i]['excerpt']  = graduate_pro_trim_content( 12, $post  );
                endif;

                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }
                $content[$i]['id']       = $page_id;
                $content[$i]['url']      = get_permalink( $page_id );
                $content[$i]['title']    = get_the_title( $page_id );

                $i++;
            }
            wp_reset_postdata();
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// testimonial section content details.
add_filter( 'graduate_pro_filter_testimonial_section_details', 'graduate_pro_get_testimonial_section_details' );


if ( ! function_exists( 'graduate_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Graduate Pro 1.0
   *
   */
   function graduate_pro_render_testimonial_section( $content_details = array() ) {
        $options  = graduate_pro_get_theme_options();
        $title    = $options['testimonial_title'];
        $testimonial_type  = $options['testimonial_content_type'];

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="testimonials" class="page-section">
            <div class="container">
                <?php if ( ! empty( $title ) ) : ?>
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                    </header>
                <?php endif; ?>

                <div class="entry-content two-columns <?php echo ( count( $content_details ) % 2 != 0 ) ? 'articles-odd-child' : 'articles-even-child'; ?>">
                    <!-- if more than 2 articles and even number -->
                    <?php 
                    $i = 1;
                    foreach ( $content_details as $content_detail ) : ?>
                        <div class="column-wrapper <?php echo ( $i == 1 ) ? 'active' : ''; ?>">
                            <article class="hentry has-post-thumbnail">
                                <figure class="featured-image">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><div style="background-image :url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')"></div></a>
                                </figure>
                                <div class="entry-container">
                                    <h2><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                    <?php if ( $testimonial_type == 'demo' ) : ?>
                                        <ul class="star-rating">
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                        </ul><!-- .star-rating -->
                                    <?php elseif ( $testimonial_type == 'testimonial' ) : 
                                        echo '<ul class="star-rating">';
                                        if ( function_exists( 'tp_testimonial_rating' ) )
                                            tp_testimonial_rating( $content_detail['id'] );
                                        echo '</ul>';
                                    endif; ?>
                                </div><!-- .entry-container -->
                            </article>
                        </div><!-- .column-wrapper -->
                    <?php $i++;
                    endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .container -->
        </section><!-- #testimonials -->

<?php 
    }
endif;