<?php
/**
 * graduate_pro options
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */

if ( ! function_exists( 'graduate_pro_enable_disable_options' ) ) :
    /**
     * Section Enable Disable
     * @return array Enable Disable options
     */
    function graduate_pro_enable_disable_options() {
      $graduate_pro_enable_disable_options = array(
        'static-frontpage'  => esc_html__( 'Static Frontpage', 'graduate-pro' ),
        'disabled'          => esc_html__( 'Disabled', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_enable_disable_options', $graduate_pro_enable_disable_options );

      return $output;
    }
endif;

if ( ! function_exists( 'graduate_pro_header_typography_options' ) ) :
    /**
     * Returns list of header typography
     * @return array font styles
     */
    function graduate_pro_header_typography_options(){

        $choices = array(
          'header-font-1'     => esc_html__( 'RAJDHANI FONT', 'graduate-pro' ),
          'header-font-2'     => esc_html__( 'CHERRY SWASH FONT', 'graduate-pro' ),
          'header-font-3'     => esc_html__( 'PHILOSOPHER FONT', 'graduate-pro' ),
          'header-font-4'     => esc_html__( 'SLABO FONT', 'graduate-pro' ),
          'header-font-5'     => esc_html__( 'DOSIS FONT', 'graduate-pro' ),
          'default'           => esc_html__( 'DEFAULT', 'graduate-pro' ),
        );
        $output = apply_filters( 'graduate_pro_header_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;

    }
endif;


if ( ! function_exists( 'graduate_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function graduate_pro_typography_options(){

        $choices = array(
          'body-font-1'     => esc_html__( 'NEWS CYCLE FONT', 'graduate-pro' ),
          'body-font-2'     => esc_html__( 'PONTANO SANS FONT', 'graduate-pro' ),
          'body-font-3'     => esc_html__( 'GUDEA FONT', 'graduate-pro' ),
          'body-font-4'     => esc_html__( 'QUATTROCENTO FONT', 'graduate-pro' ),
          'body-font-5'     => esc_html__( 'KHAND FONT', 'graduate-pro' ),
          'default'         => esc_html__( 'DEFAULT', 'graduate-pro' ),
        );
        $output = apply_filters( 'graduate_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function graduate_pro_site_layout() {
      $graduate_pro_site_layout = array(
        'wide'  => esc_html__( 'Wide', 'graduate-pro' ),
        'boxed' => esc_html__( 'Boxed', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_site_layout', $graduate_pro_site_layout );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_theme_color' ) ) :
    /**
     * Theme Color
     * @return array site theme color options
     */
    function graduate_pro_theme_color() {
      $graduate_pro_theme_color = array(
        'blue'        => esc_html__( 'Blue', 'graduate-pro' ),
        'light-blue'  => esc_html__( 'Light Blue', 'graduate-pro' ),
        'black'       => esc_html__( 'Black', 'graduate-pro' ),
        'red'         => esc_html__( 'Red', 'graduate-pro' ),
        'green'       => esc_html__( 'Green', 'graduate-pro' ),
        'yellow'      => esc_html__( 'Yellow', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_theme_color', $graduate_pro_theme_color );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function graduate_pro_sidebar_position() {
      $graduate_pro_sidebar_position = array(
        'right-sidebar' => esc_html__( 'Right', 'graduate-pro' ),
        'left-sidebar'  => esc_html__( 'Left', 'graduate-pro' ),
        'no-sidebar'    => esc_html__( 'No Sidebar', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_sidebar_position', $graduate_pro_sidebar_position );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_sidebar' ) ) :
    /**
     * Sidebar
     * @return array Sidebar
     */
    function graduate_pro_sidebar() {
      $graduate_pro_sidebar = array(
        'sidebar-1'                         => esc_html__( 'Primary Sidebar', 'graduate-pro' ),
        'graduate-pro-optional-sidebar'   => esc_html__( 'Optional Sidebar 1', 'graduate-pro' ),
        'graduate-pro-optional-sidebar-2' => esc_html__( 'Optional Sidebar 2', 'graduate-pro' ),
        'graduate-pro-optional-sidebar-3' => esc_html__( 'Optional Sidebar 3', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_sidebar', $graduate_pro_sidebar );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_header_image_options' ) ) :
    /**
     * Header image options
     * @return array Header image options
     */
    function graduate_pro_header_image_options() {
      $graduate_pro_header_image_options = array(
        'show-both' => esc_html__( 'Show Both( Featured and Header Image )', 'graduate-pro' ),
        'enable'    => esc_html__( 'Enable( Featured Image )', 'graduate-pro' ),
        'default'   => esc_html__( 'Default ( Customizer Header Image )', 'graduate-pro' ),
        'disable'   => esc_html__( 'Disable', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_header_image_options', $graduate_pro_header_image_options );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function graduate_pro_pagination_options() {
        $graduate_pro_pagination_options = array(
            'numeric'  => esc_html__( 'Numeric', 'graduate-pro' ),
            'default'  => esc_html__( 'Default(Older/Newer)', 'graduate-pro' ),
        );

      $output = apply_filters( 'graduate_pro_pagination_options', $graduate_pro_pagination_options );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_common_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function graduate_pro_common_content_type() {
      $graduate_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'page'      => esc_html__( 'Page', 'graduate-pro' ),
        'post'      => esc_html__( 'Post', 'graduate-pro' ),
        'category'  => esc_html__( 'Category', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_common_content_type', $graduate_pro_content_type );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_slider_effect' ) ) :
    /**
     * Slider effects
     * @return array Slider effects
     */
    function graduate_pro_slider_effect() {
      $graduate_pro_slider_effect = array(
        'fade'                                        => esc_html__( 'Fade', 'graduate-pro' ),
        'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'graduate-pro' ),
        'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'graduate-pro' ),
        'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'cubic', 'graduate-pro' ),
        'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'graduate-pro' ),
        'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'graduate-pro' ),
        'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'graduate-pro' ),
      );

      $output =  apply_filters( 'graduate_pro_slider_effect', $graduate_pro_slider_effect );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_slider_transition_duration' ) ) :
    /**
     * Slider transition duration
     * @return array Slider transition duration
     */
    function graduate_pro_slider_transition_duration() {
      $graduate_pro_slider_transition_duration = array(
        '1000'    => esc_html__( '1 sec', 'graduate-pro' ),
        '2000'    => esc_html__( '2 sec', 'graduate-pro' ),
        '3000'    => esc_html__( '3 sec', 'graduate-pro' ),
        '4000'    => esc_html__( '4 sec', 'graduate-pro' ),
        '5000'    => esc_html__( '5 sec', 'graduate-pro' ),
      );

      $output =  apply_filters( 'graduate_pro_slider_transition_duration', $graduate_pro_slider_transition_duration );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_about_content_type' ) ) :
    /**
     * About content types
     * @return array Content types
     */
    function graduate_pro_about_content_type() {
      $graduate_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'page'      => esc_html__( 'Page', 'graduate-pro' ),
        'post'      => esc_html__( 'Post', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_about_content_type', $graduate_pro_content_type );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_information_section_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function graduate_pro_information_section_content_type() {
      $graduate_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'page'      => esc_html__( 'Page', 'graduate-pro' ),
        'post'      => esc_html__( 'Post', 'graduate-pro' ),
        'category'  => esc_html__( 'Category', 'graduate-pro' ),
        'cat-list'  => esc_html__( 'Category List', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_common_content_type', $graduate_pro_content_type );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_information_section_column' ) ) :
    /**
     * About content types
     * @return array Content types
     */
    function graduate_pro_information_section_column() {
      $graduate_pro_information_section_column = array(
        '3'     => esc_html__( 'Three Columns', 'graduate-pro' ),
        '4'     => esc_html__( 'Four Columns', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_about_content_type', $graduate_pro_information_section_column );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_information_taxonomy_content_type' ) ) :
    /**
     * Category and Taxonomy content types
     * @return array Content types
     */
    function graduate_pro_information_taxonomy_content_type() {
      $graduate_pro_information_taxonomy_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'category'  => esc_html__( 'Category', 'graduate-pro' ),
      ); 

      $taxonomies = get_taxonomies( array( '_builtin' => false ) , 'objects' );
      if ( count( $taxonomies ) > 0 ) {
        foreach ( $taxonomies as $taxonomy ) :
          $graduate_pro_information_taxonomy_content_type = array_merge( $graduate_pro_information_taxonomy_content_type, array( $taxonomy->name => $taxonomy->labels->name ) );
        endforeach;
      }

      $output = apply_filters( 'graduate_pro_information_taxonomy_content_type', $graduate_pro_information_taxonomy_content_type );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_map_section_type' ) ) :
    /**
     * Map Content type
     * @return array site layout options
     */
    function graduate_pro_map_section_type() {
      $graduate_pro_map_section_type = array(
        'embed'     => esc_html__( 'Embed Code', 'graduate-pro' ),
        'shortcode' => esc_html__( 'Shortcode', 'graduate-pro' ),
      );

      $output = apply_filters( 'graduate_pro_map_section_type', $graduate_pro_map_section_type );

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_client_content_type' ) ) :
    /**
     * Client Section content types
     * @return array Content types
     */
    function graduate_pro_client_content_type() {
      $graduate_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'page'      => esc_html__( 'Page', 'graduate-pro' ),
        'custom'    => esc_html__( 'Custom', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_client_content_type', $graduate_pro_content_type );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;


if ( ! function_exists( 'graduate_pro_social_content_type' ) ) :
    /**
     * Social Section content types
     * @return array Content types
     */
    function graduate_pro_social_content_type() {
      $graduate_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'custom'    => esc_html__( 'Custom', 'graduate-pro' ),
      ); 

      $output = apply_filters( 'graduate_pro_social_content_type', $graduate_pro_content_type );

      // Sort array in ascending order, according to the key:
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;

if ( ! function_exists( 'graduate_pro_testimonial_content_type' ) ) :
    /**
     * Category and Taxonomy content types
     * @return array Content types
     */
    function graduate_pro_testimonial_content_type() {
      $graduate_pro_testimonial_content_type = array(
        'demo'      => esc_html__( 'Demo', 'graduate-pro' ),
        'post'      => esc_html__( 'Posts', 'graduate-pro' ),
      ); 

      if ( class_exists( 'TP_Education' ) ) {
          $graduate_pro_testimonial_content_type = array_merge( $graduate_pro_testimonial_content_type, array( 'testimonial' => 'Testimonial' ) );
      }

      $output = apply_filters( 'graduate_pro_testimonial_content_type', $graduate_pro_testimonial_content_type );

      return $output;
    }
endif;