<?php
/**
 * Instagram Widget
 *
 * @package Graduate Pro
 * @since Graduate Pro 1.0
 */

if ( ! class_exists( 'graduate_Pro_Instagram_Widget' ) ) :
	/**
	 * Instragram class.
	 * 
	 */
	class graduate_Pro_Instagram_Widget extends WP_Widget {

		/**
		 * Holds widget settings defaults, populated in constructor.
		 *
		 * @var array
		 */
		protected $defaults;

		/**
		 * Constructor. Set the default widget options and create widget.
		 *
		 * @since Graduate Pro 1.0
		 */
		function __construct() {
			$this->defaults = array(
				'title'    => esc_html__( 'Instagram', 'graduate-pro' ),
				'username' => '',
				'layout'   => 'one-column',
				'number'   => 6,
				'size'     => 'small',
				'target'   => 1,
				'link'     => 'follow',
			);

			$tp_widget_instagram = array(
				'classname'   => 'tp-instagram tpinstagram tpfeaturedpostpageimage widget_instagram',
				'description' => esc_html__( 'Displays your latest Instagram photos', 'graduate-pro' ),
			);

			$tp_control_instagram = array(
				'id_base' => 'tp-instagram',
			);

			parent::__construct(
				'tp-instagram', // Base ID
				esc_html__( 'TP: Instagram', 'graduate-pro' ), // Name
				$tp_widget_instagram,
				$tp_control_instagram
			);
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'graduate-pro' ); ?>:</label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>"><?php esc_html_e( 'Username', 'graduate-pro' ); ?>:</label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'username' ) ); ?>" value="<?php echo esc_attr( $instance['username'] ); ?>" class="widefat" />
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Layout', 'graduate-pro' ); ?>:</label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat">
					<?php
						$post_type_choices = array(
							'one-column'   => esc_html__( '1 Column', 'graduate-pro' ),
							'two-column'   => esc_html__( '2 Column', 'graduate-pro' ),
							'three-column' => esc_html__( '3 Column', 'graduate-pro' ),
						);

					foreach ( $post_type_choices as $key => $value ) {
						echo '<option value="' . esc_attr( $key ) . '" '. selected( $key, $instance['layout'], false ) .'>' . esc_html( $value ) .'</option>';
					}
					?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of photos', 'graduate-pro' ); ?>:</label>
				<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" value="<?php echo absint( $instance['number'] ); ?>" class="small-text" min="1" max="12" />
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>"><?php esc_html_e( 'Instagram Image Size', 'graduate-pro' ); ?>:</label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'size' ) ); ?>" class="widefat">
					<?php
						$post_type_choices = array(
							'thumbnail' => esc_html__( 'Thumbnail', 'graduate-pro' ),
							'small'     => esc_html__( 'Small', 'graduate-pro' ),
							'large'     => esc_html__( 'Large', 'graduate-pro' ),
							'original'  => esc_html__( 'Original', 'graduate-pro' ),
						);

					foreach ( $post_type_choices as $key => $value ) {
						echo '<option value="' . esc_attr( $key ) . '" '. selected( $key, $instance['size'], false ) .'>' . esc_html( $value ) .'</option>';
					}
					?>
				</select>
			</p>

			 <p>
	        	<input class="checkbox" type="checkbox" <?php checked( $instance['target'], true ) ?> id="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'target' ) ); ?>" />
	        	<label for="<?php echo esc_attr( $this->get_field_id('target' ) ); ?>"><?php esc_html_e( 'Check to Open Link in new Tab/Window', 'graduate-pro' ); ?></label><br />
	        </p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php esc_html_e( 'Link text', 'graduate-pro' ); ?>:
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['link'] ); ?>" /></label></p>
			<?php

		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']    = sanitize_text_field( $new_instance['title'] );
			$instance['username'] = sanitize_text_field( $new_instance['username'] );
			$instance['layout']   = sanitize_key( $new_instance['layout'] );
			$instance['number']   = absint( $new_instance['number'] );
			$instance['size']     = sanitize_key( $new_instance['size'] );
			$instance['target']   = graduate_pro_sanitize_checkbox( $new_instance['target'] );
			$instance['link']     = strip_tags( $new_instance['link'] );

			return $instance;
		}

		function widget( $args, $instance ) {
			// Merge with defaults
			$instance = wp_parse_args( (array) $instance, $this->defaults );


			// Set up the author bio
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
			}
			echo $args['before_widget'];

			$username = empty( $instance['username'] ) ? '' : $instance['username'];
			$number   = empty( $instance['number'] ) ? 9 : $instance['number'];
			$size     = empty( $instance['size'] ) ? 'large' : $instance['size'];
			$link     = empty( $instance['link'] ) ? '' : $instance['link'];

			$target = '_self';

			if ( $instance['target'] ) {
				$target = '_blank';
			}

			if ( '' != $username ) {

				$media_array = $this->scrape_instagram( $username, $number );

				if ( is_wp_error( $media_array ) ) {

					echo wp_kses_post( $media_array->get_error_message() );

				}
				else {
					// filter for images only?
					if ( $images_only = apply_filters( 'graduate_pro_images_only', FALSE ) ) {
						$media_array = array_filter( $media_array, array( $this, 'images_only' ) );
					}  
					?>

					<div class="widget-wrap">
              			<div class="instagram-profile">
                			<img src="<?php echo esc_url( $media_array['proifle_pic_url'] ); ?>" alt="<?php esc_html_e( 'instagram-profile', 'graduate-pro' ); ?>">
                			<div class="profile-name">
                			<?php if( !empty( $media_array['full_name'] ) ){ 
                				echo '<h6>'. esc_html( $media_array['full_name'] ) .'</h6>';
                			}
                			?>
	                  			<span class="username"><span><?php echo esc_html( $username );?></span>
	                		</div><!-- end .profile-name -->
              			</div>
              			<?php $linkclass = apply_filters( 'graduate_pro_link_class', 'clear' );
              			if ( '' != $link ) { ?>
              			<div class="follow-button">
                			<a href="//instagram.com/<?php echo esc_attr( trim( $username ) ); ?>" class="btn" target="<?php echo esc_attr( $target ); ?>"><i class="fa fa-instagram"></i><?php echo wp_kses_post( $link ); ?></a>
              			</div>
              			<?php } ?>
						<ul class="<?php echo esc_attr( $instance['layout'] ); ?>">
						<?php
						
							foreach ( $media_array['images_meta'] as $item ) {
								echo '
								<li>
									<a href="'. esc_url( $item['link'] ) .'" target="'. esc_attr( $target ) .'">
										<img src="'. esc_url( $item[$size] ) .'"  alt="'. esc_attr( $item['description'] ) .'" title="'. esc_attr( $item['description'] ).'"/>
									</a>
								</li>';
							}
						?>
						</ul>
					</div>
				<?php
				}
			}
			echo $args['after_widget'];
		}

		// based on https://gist.github.com/cosmocatalano/4544576
		function scrape_instagram( $username, $slice = 9 ) {
			$username = strtolower( $username );
			$username = str_replace( '@', '', $username );

			if ( false === ( $instagram = get_transient( 'instagram-a'. absint( $slice ).'-'.sanitize_title_with_dashes( $username ) ) ) ) {

				$remote = wp_remote_get( 'http://instagram.com/'.trim( $username ) );

				if ( is_wp_error( $remote ) ) {
					return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'graduate-pro' ) );
				}

				if ( 200 != wp_remote_retrieve_response_code( $remote ) ) {
					return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'graduate-pro' ) );
				}

				$shards      = explode( 'window._sharedData = ', $remote['body'] );
				$insta_json  = explode( ';</script>', $shards[1] );
				$insta_array = json_decode( $insta_json[0], TRUE );

				if ( ! $insta_array ) {
					return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'graduate-pro' ) );
				}

				if ( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ) {
					$images = $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
				}
				else {
					return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'graduate-pro' ) );
				}
				if( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['profile_pic_url'] ) ){
					$proifle_pic_url = $insta_array['entry_data']['ProfilePage'][0]['user']['profile_pic_url'];
				}
				if( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['full_name'] ) ){
					$full_name = $insta_array['entry_data']['ProfilePage'][0]['user']['full_name'];
				}else{
					$full_name = '';
				}

				if ( ! is_array( $images ) ) {
					return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'graduate-pro' ) );
				}

				$instagram = array( 'proifle_pic_url' => $proifle_pic_url, 'full_name' => $full_name );
				$instagram_images_meta = array();
				foreach ( $images as $image ) {

					$image['thumbnail_src'] = preg_replace( '/^https?\:/i', '', $image['thumbnail_src'] );
					$image['display_src']   = preg_replace( '/^https?\:/i', '', $image['display_src'] );

					// handle both types of CDN url
					if ( (strpos( $image['thumbnail_src'], 's640x640' ) !== false ) ) {
						$image['thumbnail'] = str_replace( 's640x640', 's160x160', $image['thumbnail_src'] );
						$image['small']     = str_replace( 's640x640', 's320x320', $image['thumbnail_src'] );
					}
					else {
						$urlparts  = wp_parse_url( $image['thumbnail_src'] );
						$pathparts = explode( '/', $urlparts['path'] );

						array_splice( $pathparts, 3, 0, array( 's160x160' ) );

						$image['thumbnail'] = '//' . $urlparts['host'] . implode('/', $pathparts);
						$pathparts[3]       = 's320x320';
						$image['small']     = '//' . $urlparts['host'] . implode('/', $pathparts);
					}

					$image['large'] = $image['thumbnail_src'];

					if ( $image['is_video'] == true ) {
						$type = 'video';
					}
					else {
						$type = 'image';
					}

					$caption = __( 'Instagram Image', 'graduate-pro' );
					if ( ! empty( $image['caption'] ) ) {
						$caption = $image['caption'];
					}

					$instagram_images_meta['images_meta'][] = array(
						'description'   => $caption,
						'link'		  	=> '//instagram.com/p/' . $image['code'],
						'time'		  	=> $image['date'],
						'comments'	  	=> $image['comments']['count'],
						'likes'		 	=> $image['likes']['count'],
						'thumbnail'	 	=> $image['thumbnail'],
						'small'			=> $image['small'],
						'large'			=> $image['large'],
						'original'		=> $image['display_src'],
						'type'		  	=> $type
					);
				}
				$instagram_images_meta['images_meta'] = array_slice( $instagram_images_meta['images_meta'], 0, $slice );
				$instagram =  array_merge( $instagram, $instagram_images_meta );

				// do not set an empty transient - should help catch private or empty accounts
				if ( ! empty( $instagram ) ) {
					set_transient( 'instagram-a3-'.sanitize_title_with_dashes( $username ), $instagram, apply_filters( 'graduate_pro_instagram_cache_time', HOUR_IN_SECONDS*2 ) );
				}
			}

			if ( ! empty( $instagram ) ) {
				return $instagram;
			} else {

				return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'graduate-pro' ) );

			}
		}

		function images_only( $media_item ) {
			if ( $media_item['type'] == 'image' ) {
				return true;
			}

			return false;
		}
	}
endif;

function graduate_pro_register_instagram_widget() {
	register_widget( 'graduate_Pro_Instagram_Widget' );
}
add_action( 'widgets_init', 'graduate_pro_register_instagram_widget' );
