<?php
/**
 * Custom video Widget
 *
 * @package Graduate Pro
 * @since Graduate Pro 1.0
 */

if ( ! class_exists( 'graduate_pro_video_widget' ) ) :
	/**
	 * Adds Tp video widget.
	 */
	class graduate_pro_video_widget extends WP_Widget {

		/**
		 * Register widget with WordPress.
		 */
		function __construct() {
			parent::__construct(
				'tp_video_widget', // Base ID
				esc_html__( 'TP: Video Widget', 'graduate-pro' ), // Name
				array( 'description' => esc_html__( 'An widget to upload video in sidebar.', 'graduate-pro' ), ) // Args
			);
		}


		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
			extract( $args , EXTR_SKIP );

			$title                      = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
			$tpiw_link                  = ! empty( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';
			$tpiw_alt_text              = ! empty( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';
	        $instance['link_open'] 		= '';
	        $instance['link_close'] 	= '';

	        if ( ! empty ( $tpiw_link ) ) {

				$instance['figure_open']	= '<div class="video os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><figure class="post-video">';
				$instance['link_open']  	= '<a href="' . esc_url( $tpiw_link ) . '" target="_blank" rel="prettyPhoto" class="media-link"><span class="btn btn-play"><i class="fa fa-play"></i></span>';
				$instance['link_close'] 	= '</a>';
				$instance['figure_close'] 	= '</figure></div><!-- end .video -->';
				$queryString = parse_url($tpiw_link, PHP_URL_QUERY);
				parse_str($queryString, $params);
	          	if (isset($params['v'])) {
				    $tpiw_image_url 		= "i3.ytimg.com/vi/{$params['v']}/maxresdefault.jpg";
				}

	        }
			echo $args['before_widget'];

			if ( ! empty( $tpiw_image_url ) ) {
				$sizes = array();
				$alt_text = ( ! empty( $tpiw_alt_text ) ) ? $tpiw_alt_text : basename( $tpiw_image_url );
				$imgtag = '<img src="' . esc_url( $tpiw_image_url ) . '" alt="' . esc_attr( $alt_text ) . '"/>';
				echo sprintf( '%s%s%s%s%s%s%s%s',
				$before_title,
				esc_html( $title ),
				$after_title,
				$instance['figure_open'],
				$instance['link_open'],
				$imgtag,
				$instance['link_close'],
				$instance['figure_close']
				);
	        } // End if : video is there.

			        
			echo $args['after_widget'];
		}

		/**
		 * Back-end widget form.
		 *
		 * @see WP_Widget::form()
		 *
		 * @param array $instance Previously saved values from database.
		 */
		public function form( $instance ) {
			// Defaults.
	        $instance = wp_parse_args( (array) $instance, array(
				'title'                	=>  '',
				'tpiw_link'            	=>  '',
				'tpiw_alt_text'        	=>  '',
	      	) );

			$title                		= htmlspecialchars( $instance['title'] );
			$tpiw_link                  = isset( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';
			$tpiw_alt_text              = isset( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title (Optional):', 'graduate-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>

			<p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"><?php esc_html_e( 'Video URL', 'graduate-pro' ); ?>:</label>
		        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"
		        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_link' ) ); ?>" type="text" value="<?php echo esc_url( $tpiw_link ); ?>" />
		    </p>

		    <p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"><?php esc_html_e( 'Alt Text', 'graduate-pro' ); ?>:</label>
		        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"
		        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_alt_text' ) ); ?>" type="text" value="<?php echo esc_attr( $tpiw_alt_text ); ?>" />
		    </p>
		<?php
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
			$instance                         = $old_instance;

			$instance['title']                = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
			$instance['tpiw_link']            = esc_url_raw( $new_instance['tpiw_link'] );
			$instance['tpiw_alt_text']        = sanitize_text_field( $new_instance['tpiw_alt_text'] );

			return $instance;
		}

	} // class tp_video_widget
endif;

function graduate_pro_register_video_widget() {
	register_widget( 'graduate_pro_video_widget' );
}
add_action( 'widgets_init', 'graduate_pro_register_video_widget' );
